@@ -6,8 +6,8 @@ from pip_middleware_fluig.utils.common_functions import convert_zeep_object
 
 
 class ECMDatasetService:
-    def __init__(self, client: ClientFluig = None) -> None:
-        self._client = client or ClientFluig()
+    def __init__(self, client: ClientFluig = None, wsdl_url: Optional[str]=None) -> None:
+        self._client = client or ClientFluig(wsdl_url=wsdl_url)
 
     def constraints(self, constraints: List[StructConstraint]):
         constraint_array_element = self._client.get_element_in_xml(element="ns0:searchConstraintDtoArray")
